@@ -110,7 +110,6 @@ Counts:
 **************************************************************************
 
     Author:   B. D. McKay
-              Copyright  B. McKay (2023-).  All rights reserved.
               This software is subject to the conditions and waivers
               detailed in the file COPYRIGHT.
 
@@ -138,8 +137,7 @@ boolean TLS_ATTR canonise;               /* presence of -l */
 boolean TLS_ATTR quiet;                  /* presence of -q */
 boolean TLS_ATTR header;                 /* presence of -h */
 static TLS_ATTR int kvalue,maxn,mod,res;
-#define PRUNEMULT 20   /* bigger -> more even split at greater cost */
-static TLS_ATTR int min_splitlevel,odometer,splitlevel;
+static TLS_ATTR int odometer,splitlevel;
 static TLS_ATTR graph gcan[MAXN];
 static TLS_ATTR nauty_counter nout;
 static TLS_ATTR setword *kclique; /* List of k-cliques */
@@ -150,16 +148,16 @@ static TLS_ATTR int *cliqueorbs[MAXN];
 #endif
 
 #ifdef OUTPROC
-extern void OUTPROC(FILE*,graph*,int);
+void OUTPROC(FILE*,graph*,int);
 #endif
 #ifdef PRUNE
-extern int PRUNE(graph*,int,int);
+int PRUNE(graph*,int,int);
 #endif
 #ifdef PREPRUNE
-extern int PREPRUNE(graph*,int,int);
+int PREPRUNE(graph*,int,int);
 #endif
 #ifdef SUMMARY
-extern void SUMMARY(nauty_counter,double);
+void SUMMARY(nauty_counter,double);
 #endif
 
 /************************************************************************/
@@ -217,7 +215,7 @@ automproc(int count, int *p, int *orbits,
 {
     setword *clique,w,pxi,moved;
     int ncliques;
-    int lo,hi,j,j1,j2,i,pi;
+    int lo,hi,j1,j2,i,pi;
     int *orb;
 
     ncliques = 1 + kvalue*(n - kvalue);
@@ -608,7 +606,6 @@ main(int argc, char *argv[])
     char *outfilename,sw;
     int i,j,argnum;
     graph g[MAXN];
-    int splitlevinc;
     double t1,t2;
     char msg[201];
 
@@ -623,8 +620,6 @@ main(int argc, char *argv[])
     header = FALSE;
     outfilename = NULL;
 
-    splitlevinc = 0;
-    
     gotk = gotd = gotD = gotf = gotmr = FALSE;
 
     argnum = 0;
