@@ -5,7 +5,7 @@
 /* TODO: splitlevinc */
 
 #define USAGE \
- "gentreeg [-D#] [-Z#:#] [-ulps] [-q] n [res/mod] [file]"
+ "gentreeg [-D#] [-Z#:#] [-ulps] [-q] n|n1:n2 [res/mod] [file]"
 
 #define HELPTEXT \
 " Generate (unrooted) trees.\n\
@@ -27,7 +27,7 @@
   See program text for much more information.\n"
 
 /**************************************************************
-Counts for n=1..45:
+Counts for n=1..50:
 
  1: 1
  2: 1
@@ -192,10 +192,10 @@ static char outstring[MAXOUTLEN];
 
 void (*outproc)(FILE *f, int vpar[], int n);
 #ifdef OUTPROC
-extern void OUTPROC(FILE *f, int vpar[], int n);
+void OUTPROC(FILE *f, int vpar[], int n);
 #endif
 #ifdef PRUNE
-extern int PRUNE(int vpar[], int n);
+int PRUNE(int vpar[], int n);
 #endif
 
 void WritePar(FILE *f, int vpar[], int n)
@@ -407,11 +407,12 @@ Gen( int level, int p, int s, int cL, int h, int l, int n, int f, int g )
       splitcount = mod - 1;
   }
 
-  if (p > n) 
+  if (p > n) {
      if (f == 0) {
         if (good(p-1,h,0)) Gen(level+1, p, 2, p-2,h,n,nv,1,0); 
         if (good(p-1,h,1)) Gen(level+1, p, 2, p-3,h,n,nv,1,1);
      } else { WriteIt(level);}
+  }
   else {
      if (cL == 0) {
         if ( p< ub+2 ) par[p] = p-1;
@@ -495,8 +496,7 @@ main(int argc, char *argv[])
     long Z1,Z2,Z1arg,Z2arg;
     char *outfilename,sw;
     int i,j,argnum;
-    int splitlevinc;
-    int minnv,maxnv;
+    int minnv,maxnv=1;
     double t1,t2;
     int maxdegarg;
     char msg[201];
@@ -508,8 +508,6 @@ main(int argc, char *argv[])
     qswitch = Dswitch = gotmr = gotf = irred = FALSE;
     outfilename = NULL;
 
-    splitlevinc = 0;
-    
     argnum = 0;
     for (j = 1; !badargs && j < argc; ++j)
     {
