@@ -39,13 +39,13 @@
 
 #include "gtools.h"
 
-TLS_ATTR static int *a;
-TLS_ATTR static set *colourset;
-TLS_ATTR static int *numcols;
-TLS_ATTR static set *colours;
-TLS_ATTR static set colours1[WORDSIZE];
-TLS_ATTR static setword colourset1[WORDSIZE];
-TLS_ATTR static setword numcols1[WORDSIZE];
+static TLS_ATTR int *a;
+static TLS_ATTR set *colourset;
+static TLS_ATTR int *numcols;
+static TLS_ATTR set *colours;
+static TLS_ATTR set colours1[WORDSIZE];
+static TLS_ATTR setword colourset1[WORDSIZE];
+static TLS_ATTR setword numcols1[WORDSIZE];
 
 /*******************************************************************
 * First we have code for n <= WORDSIZE. It is generally faster than
@@ -187,7 +187,7 @@ colornext1(graph *g, int n, int numsofar, int numcolors, int *color1,
           int *minsofar, setword *uncoloured, int minchi)
 {
     int i,j;
-    int vtocolour,maxnumcols;
+    int vtocolour=0,maxnumcols;
     int numnay,maxnay;
     int newnumcols;
     setword w;
@@ -426,6 +426,7 @@ colornext(graph *g, int m, int n, int numsofar, int numcolors, int *color,
         if (numcolors < *minsofar) *minsofar = numcolors;
         return;
     }
+    vtocolour = 0;
 
 #if 0
     maxnumcols = WORDSIZE-1;
@@ -458,7 +459,6 @@ colornext(graph *g, int m, int n, int numsofar, int numcolors, int *color,
         newnumcols = (i==numcolors) ? numcolors + 1 : numcolors;
 
         if (newnumcols >= *minsofar) return;
-        // if (newnumcols > minchi) return;
 
         color[vtocolour] = i;
         DELELEMENT(uncoloured,vtocolour);
